@@ -148,7 +148,7 @@ def parse_to_python_object(string):
     
     def preparse(s):
         s = s.split('\n')
-        string_regex = re.compile(r"([\w*0-9-\/\.!\[\]\#:@]+)([^-\w\"]*)(.*)", re.DOTALL)
+        string_regex = re.compile(r"([\w*0-9-\/\.!\[\]\#:@]+)([^-\w\"#]*)(.*)", re.DOTALL)
     
         for i in range(len(s)):
             s[i] = s[i].strip().replace('\e', '\\n')
